@@ -56,6 +56,9 @@ private slots:
     void createTag();
     void push();
     void pull();
+    void log();
+    void showDiff(const QUrl &link);
+    void merge();
 
     void slotOperationCompleted(int exitCode, QProcess::ExitStatus exitStatus);
     void slotOperationError();
@@ -112,6 +115,8 @@ private:
     QAction* m_tagAction;
     QAction* m_pushAction;
     QAction* m_pullAction;
+    QAction* m_logAction;
+    QAction* m_mergeAction;
 
     QString m_currentDir;
     QProcess m_process;
